@@ -1,15 +1,15 @@
 
-.First.lib <- function(lib,pkg)
+.onLoad <- function(libname,pkgname)
 {
 ver <- packageDescription("pgam",fields="Version")
 require("stats",character.only=TRUE,quietly=TRUE,warn.conflicts=FALSE)
 require("utils",character.only=TRUE,quietly=TRUE,warn.conflicts=FALSE)
 cat("This is pgam library version",ver,"\n",sep=" ")
-library.dynam("pgam","pgam")
+library.dynam("pgam",pkgname,libname)
 }
 
 
-.Last.lib <- function(libpath)
+.onUnload <- function(libpath)
 {
 # unloading process 
 library.dynam.unload("pgam",libpath)
